@@ -57,15 +57,15 @@ public:
      */
     enum ActionType {
         /// Actions which are triggered by any keypress in a widget which has the action added to it
-        WidgetAction      = Qt::WidgetShortcut      /*0*/,
+        WidgetAction = Qt::WidgetShortcut /*0*/,
         /// Actions which are triggered by any keypress in a window which has the action added to it or its child widget(s)
-        WindowAction      = Qt::WindowShortcut      /*1*/,
+        WindowAction = Qt::WindowShortcut /*1*/,
         /// Actions which are triggered by any keypress in the application
         ApplicationAction = Qt::ApplicationShortcut /*2*/,
         /// Actions which are triggered by any keypress in the windowing system
-        GlobalAction      = 4,
+        GlobalAction = 4,
         /// All actions
-        AllActions        = 0xffffffff
+        AllActions = 0xffffffff,
     };
     /**
      * Stores a combination of #ActionType values.
@@ -79,7 +79,7 @@ public:
         /// 'F1', 'Insert' etc. could still be used.
         LetterShortcutsDisallowed = 0,
         /// Letter shortcuts are allowed
-        LetterShortcutsAllowed
+        LetterShortcutsAllowed,
     };
 
     /**
@@ -91,7 +91,10 @@ public:
      * @param allowLetterShortcuts set to LetterShortcutsDisallowed if unmodified alphanumeric
      *  keys ('A', '1', etc.) are not permissible shortcuts.
      */
-    KShortcutsEditor(KActionCollection *collection, QWidget *parent, ActionTypes actionTypes = AllActions, LetterShortcuts allowLetterShortcuts = LetterShortcutsAllowed);
+    KShortcutsEditor(KActionCollection *collection,
+                     QWidget *parent,
+                     ActionTypes actionTypes = AllActions,
+                     LetterShortcuts allowLetterShortcuts = LetterShortcutsAllowed);
 
     /**
      * \overload
@@ -106,7 +109,7 @@ public:
     explicit KShortcutsEditor(QWidget *parent, ActionTypes actionTypes = AllActions, LetterShortcuts allowLetterShortcuts = LetterShortcutsAllowed);
 
     /// Destructor
-    virtual ~KShortcutsEditor();
+    ~KShortcutsEditor() override;
 
     /**
      * Are the unsaved changes?
@@ -127,8 +130,19 @@ public:
 
     /**
      * Undo all change made since the last commit().
+     *
+     * @since 5.75
      */
+    void undo();
+
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 75)
+    /**
+     * Undo all change made since the last commit().
+     * @deprecated Since 5.75, use undo()
+     */
+    KXMLGUI_DEPRECATED_VERSION(5, 75, "Use KShortcutsEditor::undo()")
     void undoChanges();
+#endif
 
     /**
      * Save the changes.
@@ -234,13 +248,10 @@ public Q_SLOTS:
      */
     void printShortcuts() const;
 
-private:
-    Q_PRIVATE_SLOT(d, void capturedShortcut(QVariant, const QModelIndex &))
-
 private:
     friend class KShortcutsDialog;
     friend class KShortcutsEditorPrivate;
-    KShortcutsEditorPrivate *const d;
+    std::unique_ptr<KShortcutsEditorPrivate> const d;
     Q_DISABLE_COPY(KShortcutsEditor)
 };
 
