@@ -105,7 +105,7 @@ ContainerNode *ContainerNode::findContainer(const QString &_name, bool tag)
         return this;
     }
 
-    for (ContainerNode *child : qAsConst(children)) {
+    for (ContainerNode *child : std::as_const(children)) {
         ContainerNode *res = child->findContainer(_name, tag);
         if (res) {
             return res;
@@ -126,16 +126,17 @@ ContainerNode *ContainerNode::findContainer(const QString &name, const QString &
     ContainerNodeList::ConstIterator nIt = children.constBegin();
 
     if (!name.isEmpty()) {
-        for (; nIt != children.constEnd(); ++nIt)
+        for (; nIt != children.constEnd(); ++nIt) {
             if ((*nIt)->name == name && !excludeList->contains((*nIt)->container)) {
                 res = *nIt;
                 break;
             }
+        }
 
         return res;
     }
 
-    if (!tagName.isEmpty())
+    if (!tagName.isEmpty()) {
         for (; nIt != children.constEnd(); ++nIt) {
             if ((*nIt)->tagName == tagName && !excludeList->contains((*nIt)->container)
                 /*
@@ -158,6 +159,7 @@ ContainerNode *ContainerNode::findContainer(const QString &name, const QString &
                 break;
             }
         }
+    }
 
     return res;
 }
@@ -166,7 +168,7 @@ ContainerClient *
 ContainerNode::findChildContainerClient(KXMLGUIClient *currentGUIClient, const QString &groupName, const MergingIndexList::iterator &mergingIdx)
 {
     if (!clients.isEmpty()) {
-        for (ContainerClient *client : qAsConst(clients)) {
+        for (ContainerClient *client : std::as_const(clients)) {
             if (client->client == currentGUIClient) {
                 if (groupName.isEmpty()) {
                     return client;
@@ -200,7 +202,7 @@ void ContainerNode::plugActionList(BuildState &state)
         plugActionList(state, mIt);
     }
 
-    for (ContainerNode *child : qAsConst(children)) {
+    for (ContainerNode *child : std::as_const(children)) {
         child->plugActionList(state);
     }
 }
@@ -238,7 +240,7 @@ void ContainerNode::unplugActionList(BuildState &state)
         unplugActionList(state, mIt);
     }
 
-    for (ContainerNode *child : qAsConst(children)) {
+    for (ContainerNode *child : std::as_const(children)) {
         child->unplugActionList(state);
     }
 }
@@ -301,10 +303,11 @@ bool ContainerNode::destruct(
 
     // remove all merging indices the client defined
     QMutableVectorIterator<MergingIndex> cmIt = mergingIndices;
-    while (cmIt.hasNext())
+    while (cmIt.hasNext()) {
         if (cmIt.next().clientName == state.clientName) {
             cmIt.remove();
         }
+    }
 
     // ### check for merging index count, too?
     if (clients.isEmpty() && children.isEmpty() && container && client == state.guiClient) {
@@ -407,14 +410,14 @@ void ContainerNode::unplugClient(ContainerClient *client)
 
     // unplug all actionslists
 
-    for (const auto &actionList : qAsConst(client->actionLists)) {
+    for (const auto &actionList : std::as_const(client->actionLists)) {
         removeActions(actionList);
     }
 }
 
 void ContainerNode::reset()
 {
-    for (ContainerNode *child : qAsConst(children)) {
+    for (ContainerNode *child : std::as_const(children)) {
         child->reset();
     }
 
@@ -447,7 +450,7 @@ void ContainerNode::dump(int offset)
     QString indent;
     indent.fill(QLatin1Char(' '), offset);
     qCDebug(DEBUG_KXMLGUI) << qPrintable(indent) << name << tagName << groupName << mergingName << mergingIndices;
-    for (ContainerNode *child : qAsConst(children)) {
+    for (ContainerNode *child : std::as_const(children)) {
         child->dump(offset + 2);
     }
 }
